Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BasicAuth ¶
func BasicAuth(username, password string) interceptor.Middleware
BasicAuth returns an interceptor that sets Basic authentication on every outgoing request.
interceptor.NewTransport(nil,
interceptors.BasicAuth("username", "password"),
)
func Header ¶
func Header(key, value string) interceptor.Middleware
Header returns an interceptor that sets a header on every outgoing request.
interceptor.NewTransport(nil,
interceptors.Header("User-Agent", "MyApp/1.0"),
)
func RequestLogging ¶
func RequestLogging(opts *RequestLoggingOptions) interceptor.Middleware
Types ¶
Click to show internal directories.
Click to hide internal directories.